context("canvasXpress Web Charts - AreaLine")


test_that("cXarealine1", {
    check_ui_test(cXarealine1())
})

test_that("cXarealine2", {
    check_ui_test(cXarealine2())
})

test_that("cXarealine3", {
    check_ui_test(cXarealine3())
})

test_that("cXarealine4", {
    check_ui_test(cXarealine4())
})
